Class: Attio::Resources::Workspaces Private
- Defined in:
- lib/attio/resources/workspaces.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
API resource for managing workspace information
Workspaces are the top-level organizational unit in Attio. Note: The workspace information is retrieved via the Meta API (/v2/self)
Instance Method Summary collapse
-
#get ⇒ Hash
private
Get current workspace information.
-
#members(**params) ⇒ Object
deprecated
private
Deprecated.
Use client.workspace_members.list instead
Constructor Details
This class inherits a constructor from Attio::Resources::Base
Instance Method Details
#get ⇒ Hash
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Get current workspace information
This method retrieves workspace info from the /v2/self endpoint which provides workspace context along with token information.
19 20 21 |
# File 'lib/attio/resources/workspaces.rb', line 19 def get request(:get, "self") end |
#members(**params) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Use client.workspace_members.list instead
24 25 26 27 |
# File 'lib/attio/resources/workspaces.rb', line 24 def members(**params) warn "[DEPRECATION] `workspaces.members` is deprecated. Use `workspace_members.list` instead." request(:get, "workspace_members", params) end |